---
name: Bug report
about: Report issues installing or running btrack
title: "[BUG]"
labels: bug
assignees: ""

---

**Describe the bug**
Please describe the bug, including any error messages. Provide screenshots if available.

**Your setup:**
Please use `btrack.SystemInformation()` to report the details of your system.

**Comments**
Add any other context about the problem here.
